@@ -104,34 +104,40 @@ def get_http_handlers(descriptor: FileDescriptor, service_name: str, method: str
     if len(await request.body()) > 0:
       body = await request.json()
     input = {**request.path_params, **request.query_params, **body}
-
+    metadata = None
     if 'Authorization' not in request.headers:
-      error_msg = 'No authorization header provided.'
-      logging.error(error_msg)
-      raise HTTPException(401, detail=error_msg)
-    authorization_header = request.headers.get('Authorization')
-    if 'Bearer ' not in authorization_header:
-      error_msg = 'Authorization header has the wrong format.'
-      logging.error(error_msg, authorization_header)
-      raise HTTPException(401, detail=error_msg)
-    _, access_token = authorization_header.split('Bearer ')
-    try:
-      decoded_access_token = await decode_token(access_token)
-    except JWTError as ex:
-      error_msg = f'Error decoding the token: {ex}'
-      logging.error(error_msg)
-      raise HTTPException(401, detail=error_msg)
-    except PublicKeyFetchError as ex:
-      error_msg = f'Error fetching jwk from keycloak: {ex}'
-      logging.error(error_msg)
-      raise HTTPException(502, detail=error_msg)
-    user = {
-      'https://delphai.com/mongo_user_id': decoded_access_token.get('mongo_user_id'),
-      'https://delphai.com/client_id': decoded_access_token.get('mongo_client_id')
-    }
-    user_json = json.dumps(user).encode('ascii')
-    user_b64 = b64encode(user_json).decode('utf-8')
-    metadata = {'x-delphai-user': user_b64}
+      logging.warn('no authorization header')
+    else:
+      authorization_header = request.headers.get('Authorization')
+      if 'Bearer ' not in authorization_header:
+        error_msg = 'Authorization header has the wrong format.'
+        logging.error(error_msg, authorization_header)
+        raise HTTPException(401, detail=error_msg)
+      _, access_token = authorization_header.split('Bearer ')
+      try:
+        decoded_access_token = await decode_token(access_token)
+      except JWTError as ex:
+        error_msg = f'Error decoding the token: {ex}'
+        logging.error(error_msg)
+        raise HTTPException(401, detail=error_msg)
+      except PublicKeyFetchError as ex:
+        error_msg = f'Error fetching jwk from keycloak: {ex}'
+        logging.error(error_msg)
+        raise HTTPException(502, detail=error_msg)
+      user = {
+        'https://delphai.com/mongo_user_id': decoded_access_token.get('mongo_user_id'),
+        'https://delphai.com/client_id': decoded_access_token.get('mongo_client_id')
+      }
+      if 'realm_access' in decoded_access_token and 'roles' in decoded_access_token.get('realm_access'):
+        roles = decoded_access_token.get('realm_access').get('roles')
+        user['roles'] = roles
+      if 'group_membership' in decoded_access_token:
+        user['groups'] = decoded_access_token['group_membership']
+      if 'limited_dataset_group_name' in decoded_access_token:
+        user['limited_dataset_group_name'] = decoded_access_token['limited_dataset_group_name']
+      user_json = json.dumps(user).encode('ascii')
+      user_b64 = b64encode(user_json).decode('utf-8')
+      metadata = {'x-delphai-user': user_b64}
 
     try:
       raw_output = await process_grpc_request(descriptor, service_name, method, input, channel, metadata=metadata)
